#include <iostream>
#include <algorithm>
#include <vector>

using namespace std;

long long gcd(long long a, long long b){
    return b == 0 ? a : gcd(b, a % b);
}

struct Tree{
    struct Segment{
        int left, right;

        Segment(int _left = 0, int _right = 0) : left(_left), right(_right) {}

        int mid(){
            return (left + right) / 2;
        }

        int size(){
            return right - left;
        }

        Segment leftMid(){
            return Segment(left, mid());
        }

        Segment midRight(){
            return Segment(mid(), right);
        }

        bool inside(Segment seg){
            return left >= seg.left && right <= seg.right;
        }
    };

    bool cross(Segment seg1, Segment seg2){
        if (seg1.left > seg2.left)
            swap(seg1, seg2);

        return seg1.right > seg2.left;
    }

    vector<long long> arr;
    vector<long long> tree;

    Tree() {}

    Tree(vector<long long> _arr) : arr(_arr) {
        tree.resize(4 * arr.size());

        build(0, Segment(0, (int)arr.size()));
    }

    void build(int pos, Segment curSeg){
        if (curSeg.size() == 1){
            tree[pos] = arr[curSeg.left];

            return;
        }

        build(2 * pos + 1, curSeg.leftMid());
        build(2 * pos + 2, curSeg.midRight());

        tree[pos] = gcd(
                        tree[2 * pos + 1],
                        tree[2 * pos + 2]);
    }

    long long getGcd(int pos, Segment curSeg, Segment query){
        if (!cross(curSeg, query)){
            return 0;
        }
        if (curSeg.inside(query)){
            return tree[pos];
        }

        return gcd(
                   getGcd(2 * pos + 1, curSeg.leftMid(), query),
                   getGcd(2 * pos + 2, curSeg.midRight(), query));
    }
};

int main(){
    ios_base::sync_with_stdio(false);
    cin.tie(NULL);
    cout.tie(NULL);

    int n, k;
    cin >> n >> k;
    vector<long long> arr(n);
    for (int i = 0; i < n; ++i)
        cin >> arr[i];

    Tree tree(arr);

    long long ans = 0;
    for (int i = 0; i < n - k + 1; ++i){
        ans = max(ans, tree.getGcd(0, Tree::Segment(0, n), Tree::Segment(i, i + k)));
        //cout << i << " " << i + k << " " << tree.getGcd(0, Tree::Segment(0, n), Tree::Segment(i, i + k)) << endl;
    }
    cout << ans << endl;

    return 0;
}
/*
10 4
2 3 4 8 12 6 12 18 4 3
*/
